%global dpf     DPF

Name:           zam-plugins
Version:        4.1
Release:        %mkrel 3
Summary:        A collection of LV2/LADSPA/JACK audio plugins
License:        GPLv2+ and ISC
Group:          System/Libraries
URL:            https://www.zamaudio.com/
Source0:        https://github.com/zamaudio/%{name}/archive/refs/tags/%{version}/%{name}-%{version}.tar.gz
Source1:        https://github.com/DISTRHO/DPF/archive/refs/heads/%{dpf}-main.zip
Source2:        https://gitlab.com/lv2/pugl/-/archive/main/pugl-main.zip

BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  ladspa-devel
BuildRequires:  pkgconfig(fftw3) >= 3.3.5
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(liblo)
BuildRequires:  pkgconfig(lv2)
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(x11)
BuildRequires:  zita-convolver-devel >= 4.0.3

# Packaged in error but may be introduced later
Obsoletes:      vst3-zam-plugins < 4.1-3.mga9
Obsoletes:      clap-zam-plugins < 4.1-3.mga9

%description
zam-plugins is a collection of LV2/LADSPA/VST/JACK audio plugins
for sound processing developed in-house at ZamAudio.


%package -n lv2-zam-plugins
Summary:        A collection of LV2/LADSPA/JACK audio plugins. LV2 version
Requires:       lv2 >= 1.8.1

%description -n lv2-zam-plugins
zam-plugins is a collection of LV2/LADSPA/VST/JACK audio plugins
for sound processing developed in-house at ZamAudio.
This is the LV2 version.


%package -n ladspa-zam-plugins
Summary:        A collection of LV2/LADSPA/JACK audio plugins. LADSPA version
Requires:       ladspa

%description -n ladspa-zam-plugins
zam-plugins is a collection of LV2/LADSPA/VST/JACK audio plugins
for sound processing developed in-house at ZamAudio.
This is the LADSPA version.

%prep
%setup -q -a 1 
# Move submodule DPF to main source directory
rmdir dpf
mv %{dpf}-main dpf
# Move submodule pugl-upstream to main source directory
%setup -q -D -a 2
rmdir dpf/dgl/src/pugl-upstream/
mv pugl-main  dpf/dgl/src/pugl-upstream

%build
# This package does not build on all arches with upstream build flags,
# so upstream build flags are split.
# These are realtime audio plugins, so we need the fastest possible math,
# flags for x86_64 are set to be compatible with most AMD and Intel CPUs,
# and to use the best possible SIMD instruction set.
flags=" -ffast-math"

%ifarch %{ix86}
flags+=" -msse -mfpmath=sse"
%endif

%ifarch x86_64
flags+=" -msse2 -mfpmath=sse"
%endif

%set_build_flags

%make_build PREFIX=%{_prefix} LIBDIR=%{_lib} USE_SYSTEM_LIBS=1 \
 BASE_OPTS="${flags}" LINK_OPTS="%{optflags}"

%install
%make_install PREFIX=%{_prefix} LIBDIR=%{_lib} USE_SYSTEM_LIBS=1
# We don't need these yet?
rm -rf %{buildroot}%{_libdir}/vst %{buildroot}%{_libdir}/vst3 %{buildroot}%{_libdir}/clap
cp -f %{_builddir}/zam-plugins-%{version}/dpf/LICENSE .

%files
%{_bindir}/*
%license NOTICE.DPF NOTICE.SFZero LICENSE
%doc README.md

%files -n lv2-zam-plugins
%{_libdir}/lv2/*
%license NOTICE.DPF NOTICE.SFZero LICENSE
%doc README.md

%files -n ladspa-zam-plugins
%{_libdir}/ladspa/*
%license NOTICE.DPF NOTICE.SFZero LICENSE
%doc README.md


%changelog
* Tue Jan 31 2023 barjac <barjac> 4.1-3.mga9
+ Revision: 1937244
- obsolete two sub-packages

* Mon Jan 30 2023 barjac <barjac> 4.1-2.mga9
+ Revision: 1937016
- dont install vst* or clap plugins yet

* Mon Jan 30 2023 barjac <barjac> 4.1-1.mga9
+ Revision: 1936998
- new version 4.1
- new sub-pkgs vst3 and clap

* Fri Dec 16 2022 philippedidier <philippedidier> 4.0-3.mga9
+ Revision: 1923782
- clean spec file
- new version 4.0

* Fri Apr 01 2022 umeabot <umeabot> 3.14-2.mga9
+ Revision: 1838547
- Mageia 9 Mass Rebuild

* Mon Dec 21 2020 barjac <barjac> 3.14-1.mga8
+ Revision: 1662574
- new version 3.14

* Mon Jul 20 2020 barjac <barjac> 3.13-1.mga8
+ Revision: 1607519
- new version 3.13

* Mon Mar 09 2020 barjac <barjac> 3.12-3.mga8
+ Revision: 1554997
- rebuild for zita-convolver

* Thu Feb 20 2020 umeabot <umeabot> 3.12-2.mga8
+ Revision: 1545761
- Mageia 8 Mass Rebuild

* Wed Jan 29 2020 barjac <barjac> 3.12-1.mga8
+ Revision: 1485231
- new version 3.12
+ wally <wally>
- replace deprecated %%setup_compile_flags

* Tue Nov 12 2019 barjac <barjac> 3.11-1.mga8
+ Revision: 1459343
- new version 3.11
- dropped upstreamed patch
- adjusted files lists

* Fri Feb 08 2019 barjac <barjac> 3.10-1.mga7
+ Revision: 1364318
- Edit spec for Mageia
- import new package from Fedora


* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 3.10-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue May 15 2018 Guido Aulisi <guido.aulisi@gmail.com> - 3.10-3
- Escape macros in changelog

* Sun May 13 2018 Guido Aulisi <guido.aulisi@gmail.com> - 3.10-2
- Use set_build_flags macro
- Document Patch0

* Wed May 9 2018 Guido Aulisi <guido.aulisi@gmail.com> - 3.10-1
- Version 3.10
